==> cssdk-1.0.02.1-sources.jar: com/css/sdk/cservice/request/URLConstant.java <==
package com.css.sdk.cservice.request;

import com.css.sdk.BuildConfig;

public class URLConstant {

    /**
     * 查询用户反馈历史
     *
     * @param
     * @return
     */
    public static String getFqaHistory() {
        return BuildConfig.CSERVICE_API + "/list";
    }

    /**
     * 查询工单详情
     *
     */
    public static String getOderDetail() {
        return BuildConfig.CSERVICE_API + "/detail";
    }

    /**
     * 用户反馈问题
     *
     */
    public static String feedbackNew() {
        return BuildConfig.CSERVICE_API + "/new";
    }

    /**
     * 用户删除工单
     *
     */
    public static String deleteWorkOrder() {
        return BuildConfig.CSERVICE_API + "/delete";
    }

    /**
     * 用户反馈问题已解决
     *
     */
    public static String feedbackFinish() {
        return BuildConfig.CSERVICE_API + "/finish";
    }

    /**
     * 用户评价工单处理结果
     *
     */
    public static String evaluate() {
        return BuildConfig.CSERVICE_API + "/evaluate";
    }

    /**
     * 上传截图
     *
     */
    public static String uploadPic() {
        return BuildConfig.CSERVICE_API + "/uploadPic";
    }

    /**
     * 查询用户推荐fqa列表
     *
     */
    public static String getFaqList() {
        return BuildConfig.CSERVICE_API + "/faq/list";
    }

    /**
     * 根据用户输入内容,查询输入结果
     */
    public static String getFaqMatch() {
        return BuildConfig.CSERVICE_API + "/faq/listMatch";
    }

    /**
     * 查看fqa内容
     *
     * @param
     * @return
     */
    public static String getFaqDetail() {
        return BuildConfig.CSERVICE_API + "/faq/detail";
    }

    /**
     * 评价fqa
     *
     */
    public static String evaluateFaq() {
        return BuildConfig.CSERVICE_API + "/faq/evaluate";
    }


}

==> cssdk-1.0.04.1-sources.jar: com/css/sdk/cservice/request/URLConstant.java <==
package com.css.sdk.cservice.request;

import com.css.sdk.BuildConfig;

public class URLConstant {

    /**
     * 查询用户反馈历史
     *
     * @param
     * @return
     */
    public static String getFqaHistory() {
        return BuildConfig.CSERVICE_API + "/list";
    }

    /**
     * 查询工单详情
     *
     */
    public static String getOderDetail() {
        return BuildConfig.CSERVICE_API + "/detail";
    }

    /**
     * 用户反馈问题
     *
     */
    public static String feedbackNew() {
        return BuildConfig.CSERVICE_API + "/new";
    }

    /**
     * 用户删除工单
     *
     */
    public static String deleteWorkOrder() {
        return BuildConfig.CSERVICE_API + "/delete";
    }

    /**
     * 用户反馈问题已解决
     *
     */
    public static String feedbackFinish() {
        return BuildConfig.CSERVICE_API + "/finish";
    }

    /**
     * 用户评价工单处理结果
     *
     */
    public static String evaluate() {
        return BuildConfig.CSERVICE_API + "/evaluate";
    }

    /**
     * 上传截图
     *
     */
    public static String uploadPic() {
        return BuildConfig.CSERVICE_API + "/uploadPic";
    }

    /**
     * 查询用户推荐fqa列表
     *
     */
    public static String getFaqList() {
        return BuildConfig.CSERVICE_API + "/faq/list";
    }


    /**
     * 查询产品的工单类型
     * added in 10023
     */
    public static String getTypeList() {
        return BuildConfig.CSERVICE_API + "/listType";
    }

    /**
     * 根据用户输入内容,查询输入结果
     */
    public static String getFaqMatch() {
        return BuildConfig.CSERVICE_API + "/faq/listMatch";
    }

    /**
     * 查看fqa内容
     *
     * @param
     * @return
     */
    public static String getFaqDetail() {
        return BuildConfig.CSERVICE_API + "/faq/detail";
    }

    /**
     * 评价fqa
     *
     */
    public static String evaluateFaq() {
        return BuildConfig.CSERVICE_API + "/faq/evaluate";
    }

    /**
     *  是否存在最新的回复
     * @return
     */
    public static String existNewReply(){
        return BuildConfig.CSERVICE_API + "/existNewReply";
    }

}
